use utf8;

package SemanticWeb::Schema::3DModel;

# ABSTRACT: A 3D model represents some kind of 3D content

use Moo;

extends qw/ SemanticWeb::Schema::MediaObject /;


use MooX::JSON_LD '3DModel';
use Ref::Util qw/ is_plain_hashref /;
# RECOMMEND PREREQ: Ref::Util::XS

use namespace::autoclean;

our $VERSION = 'v11.01.0';




1;

__END__

=pod

=encoding UTF-8

=head1 NAME

SemanticWeb::Schema::3DModel - A 3D model represents some kind of 3D content

=head1 VERSION

version v11.01.0

=head1 DESCRIPTION

A 3D model represents some kind of 3D content, which may have [[encoding]]s in one or more L<SemanticWeb::Schema::MediaObject>s. Many 3D formats are available (e.g. see L<Wikipedia|https://en.wikipedia.org/wiki/Category:3D_graphics_file_formats>); specific encoding formats can be represented using the [[encodingFormat]] property applied to the relevant L<SemanticWeb::Schema::MediaObject>. For the
case of a single file published after Zip compression, the convention of appending '+zip' to the [[encodingFormat]] can be used. Geospatial, AR/VR, artistic/animation, gaming, engineering and scientific content can all be represented using L<SemanticWeb::Schema::3DModel>.

=head1 SEE ALSO

L<SemanticWeb::Schema::MediaObject>

=head1 SOURCE

The development version is on github at L<https://github.com/robrwo/SemanticWeb-Schema>
and may be cloned from L<git://github.com/robrwo/SemanticWeb-Schema.git>

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/robrwo/SemanticWeb-Schema/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Robert Rothenberg <rrwo@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018-2020 by Robert Rothenberg.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut
